@@ -12,6 +12,7 @@ import (
 	"strings"
 	"time"
 
+	"github.com/chzyer/readline"
 	"github.com/schollz/cli/v2"
 	"github.com/schollz/croc/v9/src/comm"
 	"github.com/schollz/croc/v9/src/croc"
@@ -19,6 +20,7 @@ import (
 	"github.com/schollz/croc/v9/src/tcp"
 	"github.com/schollz/croc/v9/src/utils"
 	log "github.com/schollz/logger"
+	"github.com/schollz/mnemonicode"
 	"github.com/schollz/pake/v3"
 )
 
@@ -33,7 +35,7 @@ func Run() (err error) {
 	app := cli.NewApp()
 	app.Name = "croc"
 	if Version == "" {
-		Version = "v9.6.2-3b81934"
+		Version = "v9.6.3-5bdd445"
 	}
 	app.Version = Version
 	app.Compiled = time.Now()
@@ -95,6 +97,7 @@ func Run() (err error) {
 		&cli.BoolFlag{Name: "local", Usage: "force to use only local connections"},
 		&cli.BoolFlag{Name: "ignore-stdin", Usage: "ignore piped stdin"},
 		&cli.BoolFlag{Name: "overwrite", Usage: "do not prompt to overwrite"},
+		&cli.BoolFlag{Name: "testing", Usage: "flag for testing purposes"},
 		&cli.StringFlag{Name: "curve", Value: "p256", Usage: "choose an encryption curve (" + strings.Join(pake.AvailableCurves(), ", ") + ")"},
 		&cli.StringFlag{Name: "ip", Value: "", Usage: "set sender ip if known e.g. 10.0.0.1:9009, [::1]:9009"},
 		&cli.StringFlag{Name: "relay", Value: models.DEFAULT_RELAY, Usage: "address of the relay", EnvVars: []string{"CROC_RELAY"}},
@@ -352,6 +355,25 @@ func saveConfig(c *cli.Context, crocOptions croc.Options) {
 	}
 }
 
+type TabComplete struct{}
+
+func (t TabComplete) Do(line []rune, pos int) ([][]rune, int) {
+	var words = strings.SplitAfter(string(line), "-")
+	var lastPartialWord = words[len(words)-1]
+	var nbCharacter = len(lastPartialWord)
+	if nbCharacter == 0 {
+		// No completion
+		return [][]rune{[]rune("")}, 0
+	}
+	var strArray [][]rune
+	for _, s := range mnemonicode.WordList {
+		if strings.HasPrefix(s, lastPartialWord) {
+			strArray = append(strArray, []rune(s[nbCharacter:]))
+		}
+	}
+	return strArray, nbCharacter
+}
+
 func receive(c *cli.Context) (err error) {
 	comm.Socks5Proxy = c.String("socks5")
 	crocOptions := croc.Options{
@@ -368,6 +390,7 @@ func receive(c *cli.Context) (err error) {
 		IP:            c.String("ip"),
 		Overwrite:     c.Bool("overwrite"),
 		Curve:         c.String("curve"),
+		TestFlag:      c.Bool("testing"),
 	}
 	if crocOptions.RelayAddress != models.DEFAULT_RELAY {
 		crocOptions.RelayAddress6 = ""
@@ -429,7 +452,17 @@ func receive(c *cli.Context) (err error) {
 	}
 
 	if crocOptions.SharedSecret == "" {
-		crocOptions.SharedSecret = utils.GetInput("Enter receive code: ")
+		l, err := readline.NewEx(&readline.Config{
+			Prompt:       "Enter receive code: ",
+			AutoComplete: TabComplete{},
+		})
+		if err != nil {
+			return err
+		}
+		crocOptions.SharedSecret, err = l.Readline()
+		if err != nil {
+			return err
+		}
 	}
 	if c.String("out") != "" {
 		if err = os.Chdir(c.String("out")); err != nil {
