@@ -20,7 +20,7 @@ func TestMessage(t *testing.T) {
 	m := Message{Type: TypeMessage, Message: "hello, world"}
 	e, salt, err := crypt.New([]byte("pass"), nil)
 	assert.Nil(t, err)
-	fmt.Println(salt)
+	fmt.Println(string(salt))
 	b, err := Encode(e, m)
 	assert.Nil(t, err)
 	fmt.Printf("%x\n", b)
@@ -67,7 +67,7 @@ func TestSend(t *testing.T) {
 				log.Error(err)
 			}
 			log.Debugf("client %s connected", connection.RemoteAddr().String())
-			go func(port string, connection net.Conn) {
+			go func(_ string, connection net.Conn) {
 				c := comm.New(connection)
 				err = c.Send([]byte("hello, world"))
 				assert.Nil(t, err)
